@@ -111,7 +111,7 @@ DBSrPaintNMArea(hintTile, plane, ttype, rect, mask, func, arg)
     TileType tpt;
     int rheight, rwidth, rmax;
     dlong f1, f2, f3, f4;
-    bool ignore_sides;
+    int ignore_sides;
 
     /* If the search area is not diagonal, return the result of the	*/
     /* standard (manhattan) search function.				*/
@@ -121,7 +121,7 @@ DBSrPaintNMArea(hintTile, plane, ttype, rect, mask, func, arg)
 
     start.p_x = rect->r_xbot;
     start.p_y = rect->r_ytop - 1;
-    tp = hintTile ? hintTile : plane->pl_hint;
+    tp = hintTile ? hintTile : PlaneGetHint(plane);
     GOTOPOINT(tp, &start);
 
     /* Each iteration visits another tile on the LHS of the search area */
@@ -129,7 +129,7 @@ DBSrPaintNMArea(hintTile, plane, ttype, rect, mask, func, arg)
     {
 	/* Each iteration enumerates another tile */
 nm_enum:
-	plane->pl_hint = tp;
+	PlaneSetHint(plane, tp);
 	if (SigInterruptPending)
 	    return (1);
 
@@ -372,7 +372,7 @@ DBSrPaintArea(hintTile, plane, rect, mask, func, arg)
 
     start.p_x = rect->r_xbot;
     start.p_y = rect->r_ytop - 1;
-    tp = hintTile ? hintTile : plane->pl_hint;
+    tp = hintTile ? hintTile : PlaneGetHint(plane);
     GOTOPOINT(tp, &start);
 
     /* Each iteration visits another tile on the LHS of the search area */
@@ -380,7 +380,7 @@ DBSrPaintArea(hintTile, plane, rect, mask, func, arg)
     {
 	/* Each iteration enumerates another tile */
 enumerate:
-	plane->pl_hint = tp;
+	PlaneSetHint(plane, tp);
 	if (SigInterruptPending)
 	    return (1);
 
@@ -532,7 +532,7 @@ DBSrPaintClient(hintTile, plane, rect, mask, client, func, arg)
 
     start.p_x = rect->r_xbot;
     start.p_y = rect->r_ytop - 1;
-    tp = hintTile ? hintTile : plane->pl_hint;
+    tp = hintTile ? hintTile : PlaneGetHint(plane);
     GOTOPOINT(tp, &start);
 
     /* Each iteration visits another tile on the LHS of the search area */
@@ -540,7 +540,7 @@ DBSrPaintClient(hintTile, plane, rect, mask, client, func, arg)
     {
 	/* Each iteration enumerates another tile */
 enumerate:
-	plane->pl_hint = tp;
+	PlaneSetHint(plane, tp);
 	if (SigInterruptPending)
 	    return (1);
 
@@ -657,7 +657,7 @@ DBResetTilePlane(plane, cdata)
     ClientData cdata;
 {
     Tile *tp, *tpnew;
-    Rect *rect = &TiPlaneRect;
+    const Rect *rect = &TiPlaneRect;
 
     /* Start with the leftmost non-infinity tile in the plane */
     tp = TR(plane->pl_left);
@@ -723,9 +723,7 @@ enumerate:
  *
  * This procedure uses a carfully constructed non-recursive area
  * enumeration algorithm.  Care is taken to not access a tile that has
- * been deallocated.  The only exception is for a tile that has just been
- * passed to free(), but no more calls to free() or malloc() have been made.
- * Magic's malloc allows this.
+ * been deallocated.
  *
  * --------------------------------------------------------------------
  */
@@ -735,11 +733,12 @@ DBFreePaintPlane(plane)
     Plane *plane;	/* Plane whose storage is to be freed */
 {
     Tile *tp, *tpnew;
-    Rect *rect = &TiPlaneRect;
+    const Rect *rect = &TiPlaneRect;
 
     /* Start with the bottom-right non-infinity tile in the plane */
     tp = BL(plane->pl_right);
 
+    Tile *delayed = NULL;
     /* Each iteration visits another tile on the RHS of the search area */
     while (BOTTOM(tp) < rect->r_ytop)
     {
@@ -762,9 +761,9 @@ enumerate:
 	/* Each iteration returns one tile further to the right */
 	while (RIGHT(tp) < rect->r_xtop)
 	{
-	    TiFree(tp);
-	    tpnew = RT(tp);
-	    tp = TR(tp);
+	    TiFree1(&delayed, tp);
+	    tpnew = RT(tp); /* deref of delayed */
+	    tp = TR(tp); /* deref of delayed */
 	    if (CLIP_TOP(tpnew) <= CLIP_TOP(tp) && BOTTOM(tpnew) < rect->r_ytop)
 	    {
 		tp = tpnew;
@@ -772,13 +771,14 @@ enumerate:
 	    }
 	}
 
-	TiFree(tp);
+	TiFree1(&delayed, tp);
 	/* At right edge -- walk up to next tile along the right edge */
-	tp = RT(tp);
+	tp = RT(tp); /* deref of delayed */
 	if (BOTTOM(tp) < rect->r_ytop) {
 	    while(LEFT(tp) >= rect->r_xtop) tp = BL(tp);
 	}
     }
+    TiFreeIf(delayed);
 }
 
 /*
