@@ -478,34 +478,18 @@ drcTile (tile, arg)
 	int deltax, deltay;
 	TileType tt, to;
 
-	/* Check rules for DRC_ANGLES_90 rule and process */
-	tt = TiGetLeftType(tile);
-	if (tt != TT_SPACE)
-	{
-	    for (cptr = DRCCurStyle->DRCRulesTbl[TT_SPACE][tt];
-			cptr != (DRCCookie *) NULL; cptr = cptr->drcc_next)
-		if (cptr->drcc_flags & DRC_ANGLES_90)
-		{
-		    drcCheckAngles(tile, arg, cptr);
-		    break;
-		}
-	}
-	tt = TiGetRightType(tile);
-	if (tt != TT_SPACE)
-	{
-	    for (cptr = DRCCurStyle->DRCRulesTbl[TT_SPACE][tt];
-			cptr != (DRCCookie *) NULL; cptr = cptr->drcc_next)
-		if (cptr->drcc_flags & DRC_ANGLES_90)
-		{
-		    drcCheckAngles(tile, arg, cptr);
-		    break;
-		}
-	}
-
-	/* Full check of edge rules along the diagonal. */
 	tt = TiGetLeftType(tile);	/* inside type */
 	to = TiGetRightType(tile);	/* outside type */
 
+	/* Check rules for DRC_ANGLES_90 rule and process */
+	for (cptr = DRCCurStyle->DRCRulesTbl[to][tt];
+			cptr != (DRCCookie *) NULL; cptr = cptr->drcc_next)
+	    if (cptr->drcc_flags & DRC_ANGLES_90)
+	    {
+		drcCheckAngles(tile, arg, cptr);
+		break;
+	    }
+
 	for (cptr = DRCCurStyle->DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
 			cptr = cptr->drcc_next)
 	{
@@ -839,7 +823,7 @@ drcTile (tile, arg)
 			    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tpr)))
 		 	    {
 				errRect.r_ybot -= cdist;
-				if (DRCEuclidean)
+				if (DRCEuclidean && !(cptr->drcc_flags & DRC_MANHATTAN))
 				    arg->dCD_radial |= RADIAL_SW;
 			    }
 			}
@@ -867,7 +851,8 @@ drcTile (tile, arg)
 					TiGetBottomType(tpr)))
 				{
 				    errRect.r_ytop += cdist;
-				    if (DRCEuclidean)
+				    if (DRCEuclidean &&
+						!(cptr->drcc_flags & DRC_MANHATTAN))
 					arg->dCD_radial |= RADIAL_NW;
 				}
 			    }
@@ -913,7 +898,7 @@ drcTile (tile, arg)
 			    if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tpl)))
 			    {
 				errRect.r_ytop += cdist;
-				if (DRCEuclidean)
+				if (DRCEuclidean && !(cptr->drcc_flags & DRC_MANHATTAN))
 				    arg->dCD_radial |= RADIAL_NE;
 			    }
 			}
@@ -940,7 +925,8 @@ drcTile (tile, arg)
 				if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tpl)))
 				{
 				    errRect.r_ybot -= cdist;
-				    if (DRCEuclidean)
+				    if (DRCEuclidean &&
+						!(cptr->drcc_flags & DRC_MANHATTAN))
 					arg->dCD_radial |= RADIAL_SE;
 				}
 			    }
@@ -1212,7 +1198,7 @@ drcTile (tile, arg)
 		 	if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tpx)))
 			{
 			    errRect.r_xtop += cdist;
-			    if (DRCEuclidean)
+			    if (DRCEuclidean && !(cptr->drcc_flags & DRC_MANHATTAN))
 				arg->dCD_radial |= RADIAL_SE;
 			}
 
@@ -1229,7 +1215,7 @@ drcTile (tile, arg)
 			    if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tpx)))
 			    {
 				errRect.r_xbot -= cdist;
-				if (DRCEuclidean)
+				if (DRCEuclidean && !(cptr->drcc_flags & DRC_MANHATTAN))
 				    arg->dCD_radial |= RADIAL_SW;
 			    }
 			}
@@ -1266,7 +1252,7 @@ drcTile (tile, arg)
 			if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tpx)))
 			{
 			    errRect.r_xbot -= cdist;
-			    if (DRCEuclidean)
+			    if (DRCEuclidean && !(cptr->drcc_flags & DRC_MANHATTAN))
 				arg->dCD_radial |= RADIAL_NW;
 			}
 
@@ -1282,7 +1268,7 @@ drcTile (tile, arg)
 			    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tpx)))
 			    {
 				errRect.r_xtop += cdist;
-				if (DRCEuclidean)
+				if (DRCEuclidean && !(cptr->drcc_flags & DRC_MANHATTAN))
 				    arg->dCD_radial |= RADIAL_NE;
 			    }
 			}
